@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,9 @@
 
 #include "actiontype.h"
 
-template<>
-QStringList ActionType::TemplateType<ActionType>::type_names =
+QStringList ActionType::type_names =
 {
-	"", // Reserved for BaseType::null
+	"", // Reserved for Class::Null
 
 	"NO ACTION",
 	"RESTRICT",
@@ -44,3 +43,23 @@ ActionType::ActionType()
 {
 	type_idx = NoAction;
 }
+
+QStringList ActionType::getTypes()
+{
+	return TemplateType<ActionType>::getTypes(type_names);
+}
+
+unsigned ActionType::setType(unsigned type_id)
+{
+	return TemplateType<ActionType>::setType(type_id, type_names);
+}
+
+unsigned ActionType::setType(const QString &type_name)
+{
+	return TemplateType<ActionType>::setType(type_name, type_names);
+}
+
+QString ActionType::getTypeName(unsigned type_id)
+{
+	return TemplateType<ActionType>::getTypeName(type_id, type_names);
+}
