@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,9 @@
 
 #include "eventtype.h"
 
-template<>
-QStringList EventType::TemplateType<EventType>::type_names =
+QStringList EventType::type_names =
 {
-	"", // Reserved for BaseType::null
+	"", // Reserved for Class::Null
 
 	"ON SELECT",
 	"ON INSERT",
@@ -35,6 +34,11 @@ EventType::EventType()
 	type_idx = OnSelect;
 }
 
+QStringList EventType::getTypes()
+{
+	return TemplateType<EventType>::getTypes(type_names);
+}
+
 EventType::EventType(const QString &type_name)
 {
 	setType(type_name);
@@ -54,3 +58,18 @@ bool EventType::operator < (unsigned type_id) const
 {
 	return (type_idx < type_id);
 }
+
+unsigned EventType::setType(unsigned type_id)
+{
+	return TemplateType<EventType>::setType(type_id, type_names);
+}
+
+unsigned EventType::setType(const QString &type_name)
+{
+	return TemplateType<EventType>::setType(type_name, type_names);
+}
+
+QString EventType::getTypeName(unsigned type_id)
+{
+	return TemplateType<EventType>::getTypeName(type_id, type_names);
+}
