@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,7 +27,10 @@
 
 #include "templatetype.h"
 
-class PartitioningType: public TemplateType<PartitioningType> {
+class __libcore PartitioningType: public TemplateType<PartitioningType> {
+	private:
+		static QStringList type_names;
+
 	public:
 		static constexpr unsigned Range = 1,
 		List = 2,
@@ -36,6 +39,12 @@ class PartitioningType: public TemplateType<PartitioningType> {
 		PartitioningType(const QString &type_name);
 		PartitioningType(unsigned type_id);
 		PartitioningType();
+
+		static QStringList getTypes();
+
+		unsigned setType(unsigned type_id) override;
+		unsigned setType(const QString &type_name) override;
+		QString getTypeName(unsigned type_id) override;
 };
 
 #endif 
