@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,10 +30,14 @@ class __libcore Procedure: public BaseFunction {
 	public:
 		Procedure();
 
-		virtual void addParameter(Parameter param);
+		virtual ~Procedure(){}
+
+		virtual void addParameter(Parameter param) override;
 		virtual QString getSourceCode(SchemaParser::CodeType def_type, bool) final;
 		virtual QString getSourceCode(SchemaParser::CodeType def_type) final;
 		virtual QString getAlterCode(BaseObject *object) final;
+
+		virtual void updateDependencies() override;
 };
 
 #endif
