@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 */
 
 #include "baseform.h"
+#include "guiutilsns.h"
 
 BaseForm::BaseForm(QWidget *parent, Qt::WindowFlags f) : QDialog(parent, f)
 {
@@ -33,9 +34,27 @@ void BaseForm::setButtonConfiguration(Messagebox::ButtonsId button_conf)
 	}
 	else
 	{
-		apply_ok_btn->setText(tr("&Ok"));
+		if(button_conf==Messagebox::CloseButton)
+		{
+			apply_ok_btn->setText(tr("&Close"));
+			apply_ok_btn->setIcon(QIcon(GuiUtilsNs::getIconPath("close1")));
+		}
+		else
+		{
+			apply_ok_btn->setText(tr("&Ok"));
+			apply_ok_btn->setIcon(QIcon(GuiUtilsNs::getIconPath("confirm")));
+		}
+
 		cancel_btn->setVisible(false);
 	}
+
+	apply_ok_btn->setDefault(button_conf != Messagebox::CloseButton);
+}
+
+void BaseForm::adjustMinimumSize()
+{
+	adjustSize();
+	setMinimumSize(size());
 }
 
 void BaseForm::resizeForm(QWidget *widget)
@@ -47,9 +66,10 @@ void BaseForm::resizeForm(QWidget *widget)
 	QSize min_size=widget->minimumSize();
 	int max_h = 0, max_w = 0, curr_w =0, curr_h = 0;
 	QScreen *screen = qApp->primaryScreen();
+	QSize screen_sz = screen->size();
 
-	max_w = screen->size().width() * 0.70;
-	max_h = screen->size().height() * 0.70;
+	max_w = screen_sz.width() * 0.70;
+	max_h = screen_sz.height() * 0.70;
 	vbox->setContentsMargins(0, 0, 0, 0);
 
 	/* If the widget's minimum size is zero then we need to do
@@ -57,7 +77,7 @@ void BaseForm::resizeForm(QWidget *widget)
 	if(min_size.height() <= 0 || min_size.width() <= 0)
 	{
 		widget->adjustSize();
-		min_size=widget->size();
+		min_size = widget->size();
 	}
 
 	//Insert the widget into a scroll area if it's minimum size exceeds the 70% of screen's dimensions
@@ -98,11 +118,11 @@ void BaseForm::resizeForm(QWidget *widget)
 							((buttons_lt->contentsMargins().top() +
 								buttons_lt->contentsMargins().bottom()) * 6);
 
-	if(curr_w > screen->size().width())
-		curr_w = screen->size().width() * 0.80;
+	if(curr_w > screen_sz.width())
+		curr_w = screen_sz.width() * 0.80;
 
-	if(curr_h > screen->size().height())
-		curr_h = screen->size().height() * 0.80;
+	if(curr_h > screen_sz.height())
+		curr_h = screen_sz.height() * 0.80;
 
 	this->setMinimumSize(min_size);
 	this->resize(curr_w, curr_h);
@@ -114,26 +134,6 @@ void BaseForm::closeEvent(QCloseEvent *)
 	this->reject();
 }
 
-void BaseForm::setMainWidget(BaseObjectWidget *widget)
-{
-	if(!widget)
-		return;
-
-	if(widget->getHandledObjectType()!=ObjectType::BaseObject && widget->windowTitle().isEmpty())
-		setWindowTitle(tr("%1 properties").arg(BaseObject::getTypeName(widget->getHandledObjectType())));
-	else
-		setWindowTitle(widget->windowTitle());
-
-	apply_ok_btn->setDisabled(widget->isHandledObjectProtected());
-	resizeForm(widget);
-	setButtonConfiguration(Messagebox::OkCancelButtons);
-
-	connect(cancel_btn, &QPushButton::clicked, widget, &BaseObjectWidget::cancelConfiguration);
-	connect(cancel_btn, &QPushButton::clicked, this, &BaseForm::reject);
-	connect(apply_ok_btn, &QPushButton::clicked, widget, &BaseObjectWidget::applyConfiguration);
-	connect(widget, &BaseObjectWidget::s_closeRequested, this, &BaseForm::accept);
-}
-
 void BaseForm::setMainWidget(QWidget *widget)
 {
 	if(!widget)	return;
