@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2023 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,11 @@
 */
 
 #include "columnpickerwidget.h"
+#include "guiutilsns.h"
+#include "table.h"
+#include "view.h"
+#include "relationship.h"
+#include "messagebox.h"
 
 ColumnPickerWidget::ColumnPickerWidget(QWidget *parent) :	QWidget(parent)
 {
@@ -38,15 +43,15 @@ ColumnPickerWidget::ColumnPickerWidget(QWidget *parent) :	QWidget(parent)
 	col_picker_grid->addWidget(columns_tab, 1, 0, 1, 3);
 
 	connect(columns_tab, &ObjectsTableWidget::s_rowAdded, this, [this](int idx){
-		addColumn(idx);
+		__trycatch( addColumn(idx); )
 	});
 
 	connect(columns_tab, &ObjectsTableWidget::s_rowRemoved, this, [this](int){
-		updateColumnsCombo();
+		__trycatch( updateColumnsCombo(); )
 	});
 
 	connect(columns_tab, &ObjectsTableWidget::s_rowsRemoved, this, [this](){
-		updateColumnsCombo();
+		__trycatch( updateColumnsCombo(); )
 	});
 
 	setParentObject(nullptr);
@@ -54,22 +59,29 @@ ColumnPickerWidget::ColumnPickerWidget(QWidget *parent) :	QWidget(parent)
 
 void ColumnPickerWidget::setParentObject(BaseObject *p_obj)
 {
-	/* Currently, column picker supports only tables and relatinoships.
+	try
+	{
+		/* Currently, column picker supports only tables and relatinoships.
 	 * Since views can't handle columns yet they will be ignored */
-	if(p_obj &&
-		 p_obj->getObjectType() != ObjectType::Table &&
-		 p_obj->getObjectType() != ObjectType::View &&
-		 p_obj->getObjectType() != ObjectType::Relationship)
-		p_obj = nullptr;
+		if(p_obj &&
+				p_obj->getObjectType() != ObjectType::Table &&
+				p_obj->getObjectType() != ObjectType::View &&
+				p_obj->getObjectType() != ObjectType::Relationship)
+			p_obj = nullptr;
 
-	parent_obj = p_obj;
-	setEnabled(p_obj != nullptr);
+		parent_obj = p_obj;
+		setEnabled(p_obj != nullptr);
 
-	columns_tab->blockSignals(true);
-	columns_tab->removeRows();
-	columns_tab->blockSignals(false);
+		columns_tab->blockSignals(true);
+		columns_tab->removeRows();
+		columns_tab->blockSignals(false);
 
-	updateColumnsCombo();
+		updateColumnsCombo();
+	}
+	catch(Exception &e)
+	{
+		throw Exception(e.getErrorMessage(),e.getErrorCode(),__PRETTY_FUNCTION__,__FILE__,__LINE__, &e);
+	}
 }
 
 void ColumnPickerWidget::setColumns(const std::vector<Column *> &cols)
@@ -153,11 +165,12 @@ void ColumnPickerWidget::updateColumnsCombo()
 			{
 				//If the column does not exists on the column's table, adds it
 				if(columns_tab->getRowIndex(QVariant::fromValue<SimpleColumn>(col)) < 0)
-					columns_cmb->addItem(QString("%1 (%2)").arg(col.name, col.type), QVariant::fromValue<SimpleColumn>(col));
+					columns_cmb->addItem(QString("%1 (%2)").arg(col.getName(), col.getType()), QVariant::fromValue<SimpleColumn>(col));
 			}
 		}
 
 		columns_tab->setButtonsEnabled(ObjectsTableWidget::AddButton, columns_cmb->count() != 0);
+		columns_cmb->adjustSize();
 	}
 	catch(Exception &e)
 	{
@@ -225,11 +238,11 @@ void ColumnPickerWidget::addColumn(Column *column, int row)
 
 void ColumnPickerWidget::addColumn(const SimpleColumn &column, int row)
 {
-	if(column.name.isEmpty() || row < 0)
+	if(column.getName().isEmpty() || row < 0)
 		return;
 
-	columns_tab->setCellText(column.name, row, 0);
-	columns_tab->setCellText(column.type, row, 1);
+	columns_tab->setCellText(column.getName(), row, 0);
+	columns_tab->setCellText(column.getType(), row, 1);
 	columns_tab->setRowData(QVariant::fromValue<SimpleColumn>(column), row);
 }
 
@@ -255,3 +268,8 @@ std::vector<SimpleColumn> ColumnPickerWidget::getSimpleColumns()
 
 	return cols;
 }
+
+void ColumnPickerWidget::clear()
+{
+	columns_tab->removeRows();
+}
