@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "pgsqltypewidget.h"
 #include "ui_operatorwidget.h"
 
-class OperatorWidget: public BaseObjectWidget, public Ui::OperatorWidget {
+class __libgui OperatorWidget: public BaseObjectWidget, public Ui::OperatorWidget {
 	private:
 		Q_OBJECT
 
