@@ -1,7 +1,7 @@
 /*
 # PostgreSQL Database Modeler (pgModeler)
 #
-# Copyright 2006-2021 - Raphael Araújo e Silva <raphael@pgmodeler.io>
+# Copyright 2006-2024 - Raphael Araújo e Silva <raphael@pgmodeler.io>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "baseobjectwidget.h"
 #include "ui_tablespacewidget.h"
 
-class TablespaceWidget: public BaseObjectWidget, public Ui::TablespaceWidget {
+class __libgui TablespaceWidget: public BaseObjectWidget, public Ui::TablespaceWidget {
 	private:
 		Q_OBJECT
 
